util

package
v0.0.13 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 14, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CleanPath

func CleanPath(relativePath string) string

CleanPath tries to turn any path into a usable path (cleans up, expands ~ to home dir, and tries to turn it into an absolute path)

func ConfirmAction

func ConfirmAction(prompt string) error

func ConfirmRunIfRoot

func ConfirmRunIfRoot() bool

func CreateDir

func CreateDir(path string) error

func Delete

func Delete(path string) error

func Exists

func Exists(path string) (bool, error)

func FormatHeader

func FormatHeader(title string) string

func IsRoot

func IsRoot() bool

func IsValidFolderName

func IsValidFolderName(name string) bool

func WriteConfigFile

func WriteConfigFile(path string, data []byte) error

Types

This section is empty.

Jump to