Documentation
¶
Index ¶
- func CleanPath(relativePath string) string
- func ConfirmAction(prompt string) error
- func ConfirmRunIfRoot() bool
- func CreateDir(path string) error
- func Delete(path string) error
- func Exists(path string) (bool, error)
- func FormatHeader(title string) string
- func IsRoot() bool
- func IsValidFolderName(name string) bool
- func WriteConfigFile(path string, data []byte) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CleanPath ¶
CleanPath tries to turn any path into a usable path (cleans up, expands ~ to home dir, and tries to turn it into an absolute path)
func ConfirmAction ¶
func ConfirmRunIfRoot ¶
func ConfirmRunIfRoot() bool
func FormatHeader ¶
func IsValidFolderName ¶
func WriteConfigFile ¶
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.